@@ -13,8 +13,6 @@
 namespace GraphTheory
 {
 
-class Rocs1FileFormatPrivate;
-
 /** \brief class RocsGraphFileFormatPlugin: Import and Export Plugin for internal graph format.
  *
  * A Document Internal format may look like this:
@@ -102,14 +100,12 @@ class Rocs1FileFormatPrivate;
  * property3 : propertyValue3
  */
 
-
-
 class Rocs1FileFormat : public FileFormatInterface
 {
     Q_OBJECT
 
 public:
-    explicit Rocs1FileFormat(QObject *parent, const QList< QVariant >&);
+    explicit Rocs1FileFormat(QObject *parent, const KPluginMetaData &data, const QVariantList &);
     ~Rocs1FileFormat() override;
 
     /**
@@ -133,7 +129,7 @@ private:
     QString serialize(GraphDocumentPtr document);
     void serializeProperties(QObject *o);
 
-    Rocs1FileFormatPrivate *d;
+    QString m_buffer;
 };
 }
 
